@@ -34,9 +34,9 @@ NNS.TSD <- function(x, y){
     lines(LPM_y_sort, type = "l", lwd =3,col = "blue")
     legend("topleft", c("X","Y"), lwd = 10, col=c("red","blue"))
 
-    ifelse (!x.tsd.y & min(x) >= min(y) & mean(x) >= mean(y) & !identical(LPM_x_sort, LPM_y_sort),
+    ifelse (!x.tsd.y & min(x) >= min(y) && mean(x) >= mean(y) && !identical(LPM_x_sort, LPM_y_sort),
             "X TSD Y",
-            ifelse (!y.tsd.x & min(y) >= min(x)& mean(y) >= mean(x) & !identical(LPM_x_sort, LPM_y_sort),
+            ifelse (!y.tsd.x && min(y) >= min(x) && mean(y) >= mean(x) && !identical(LPM_x_sort, LPM_y_sort),
                     "Y TSD X",
                     "NO TSD EXISTS"))
 
